@@ -2,8 +2,9 @@ use super::{
     crawl_candlestick_ext, crawl_event,
     utils::{check_args, fetch_symbols_retry},
 };
-use crate::{crawlers::utils::create_conversion_thread, msg::Message, MessageType};
-use crypto_markets::MarketType;
+use crate::{crawlers::utils::create_conversion_thread, msg::Message};
+use crypto_market_type::MarketType;
+use crypto_msg_type::MessageType;
 use crypto_ws_client::*;
 use std::sync::mpsc::Sender;
 
